object-validator
================

Flexible JSON syntax for customized form validation.

NOTE: If you are updating to version 1.1.0 or higher, the errors() method now returns an object instead of a key-value array (see updated usage for more details).


Usage
-----
Require the package:

    var validate = require('object-validator');


Lay out your form rules:

    var form = [
        {
            name: 'email',
            input: 'foo@bar',
            rules: [
                {
                    name: 'required',
                    message: 'The email field is required'
                },
                {
                    name: 'email',
                    message: 'You must provide a valid email address.'
                }
            ]
        },
        {
            name: 'firstName',
            input: 'P',
            rules: [
                {
                    name: 'required',
                    message: 'Your first name is required.'
                },
                {
                    name: { min: 2 },
                    message: 'Your first name must be at least 2 characters.'
                },
                {
                    name: { max: 20 },
                    message: 'Your first name cannot exceed 20 characters.'
                },
                {
                    name: 'alpha',
                    message: 'Your first name can contain only alphabetic characters.'
                }
            ]
        },
        {
            name: 'lastName',
            input: 'Doe',
            rules: [
                {
                    name: 'required',
                    message: 'Your last name is required.'
                }
            ]
        }
    ];


Run the validator:

    if (validate(form))
    {
        // Form has passed validation
        // Add something to the database
    }
    else
    {
        // Form has failed validation
        // Get the errors
        var errors = validate.errors();
    }


Let's say the form failed validation. The validate.errors() method will return this:

    {
        email: {
            rule: 'email',
            message: 'You must provide a valid email address.'
        },
        firstName: {
            rule: 'min',
            message: 'Your first name must be at least 2 characters.'
        },
        lastName: {}
    }


Then you can just send it to your view:

    res.render('view', { errors: validate.errors() });


And use them however you'd like:

    // view.jade
    form
        p.error= errors.email.message
        input(type='text', name='email')

        p.error= errors.firstName.message
        input(type='text', name='firstName')

        p.error= errors.lastName.message
        input(type='text', name='lastName')


Available Rules
---------------
 - 'required' - input cannot be null
 - 'email' - input must be a proper email
 - 'url' - input must be a URL
 - 'ip' - input must be an IP
 - 'alpha' - input must only contain alphabetic characters
 - 'numeric' - input must only contain numbers
 - 'alphanumeric' - input can only contain numbers and letters
 - 'hex' - input must be hexadecimal
 - 'lowercase' - input must be all lowercase
 - 'uppercase' - input must be all uppercase
 - 'int' - input must be an integer
 - 'float' - input must be a float
 - 'date' - input must be a date
 - 'json' - input must be valid JSON
 - { divisible: num } - input must be divisible by 'num'
 - { min: num } - input must be at least 'num' characters long
 - { max: num } - input cannot be more than 'num' characters
 - { contains: 'my string' } - input must contain 'my string'


About
-----
#### Tests
Simply run `npm test` to run the mocha tests.

#### License

    Copyright (c) 2014, Paul Dilyard

    Permission to use, copy, modify, and/or distribute this software for any purpose with or without fee is hereby granted, provided that the above copyright notice and this permission notice appear in all copies.

    THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

#### Contributors
Special thanks to the developers of validator.js; this package uses validator to check for most of its rules.
