/*
|--------------------------------------------------------------------------
| Object Validator
|--------------------------------------------------------------------------
| Paul Dilyard <paul.dilyard@gmail.com>
|
| Easy object-based syntax for form validation.
|
|--------------------------------------------------------------------------
| License
|--------------------------------------------------------------------------
|
| Copyright (c) 2014, Paul Dilyard
|
| Permission to use, copy, modify, and/or distribute this software for any
| purpose with or without fee is hereby granted, provided that the above
| copyright notice and this permission notice appear in all copies.
|
| THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
| WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
| MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
| ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
| WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
| ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
| OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
|
*/

// Dependencies
var validator = require('validator');

// Hold the errors
var errors = {};
var pass = true;

module.exports = function (form) {

    errors = {};
    pass = true;

    // Loop through form
    for (var i = 0; i < form.length; ++i)
    {
        check(form[i]);
    }

    return pass;

};

module.exports.errors = function () {

    return errors;

};

function check (field) {

    // Loop through all rules
    for (var i = 0; i < field.rules.length; ++i)
    {
        if (error(field.name, field.input, field.rules[i]))
            break;
    }

}

function error (name, input, rule) {

    var err = false;

    // Check for all errors

    if (rule.name == 'required')
    {
        if (validator.isNull(input))
        {
            errors[name] = {
                rule: rule.name,
                message: rule.message
            };
            pass = false;
            err = true;
        }
        else
        {
            errors[name] = {};
        }
    }

    else if (rule.name.contains)
    {
        if (!validator.contains(input, rule.name.contains))
        {
            errors[name] = {
                rule: 'contains',
                message: rule.message
            };
        }
        else
        {
            errors[name] = {};
        }
    }

    else if (rule.name == 'email')
    {
        if (!validator.isEmail(input))
        {
            errors[name] = {
                rule: rule.name,
                message: rule.message
            };
            pass = false;
            err = true;
        }
        else
        {
            errors[name] = {};
        }
    }

    else if (rule.name == 'url')
    {
        if (!validator.isURL(input))
        {
            errors[name] = {
                rule: rule.name,
                message: rule.message
            };
            pass = false;
            err = true;
        }
        else
        {
            errors[name] = {};
        }
    }

    else if (rule.name == 'ip')
    {
        if (!validator.isIP(input))
        {
            errors[name] = {
                rule: rule.name,
                message: rule.message
            };
            pass = false;
            err = true;
        }
        else
        {
            errors[name] = {};
        }
    }

    else if (rule.name == 'alpha')
    {
        if (!validator.isAlpha(input))
        {
            errors[name] = {
                rule: rule.name,
                message: rule.message
            };
            pass = false;
            err = true;
        }
        else
        {
            errors[name] = {};
        }
    }

    else if (rule.name == 'numeric')
    {
        if (!validator.isNumeric(input))
        {
            errors[name] = {
                rule: rule.name,
                message: rule.message
            };
            pass = false;
            err = true;
        }
        else
        {
            errors[name] = {};
        }
    }

    else if (rule.name == 'alphanumeric')
    {
        if (!validator.isAlphanumeric(input))
        {
            errors[name] = {
                rule: rule.name,
                message: rule.message
            };
            pass = false;
            err = true;
        }
        else
        {
            errors[name] = {};
        }
    }

    else if (rule.name == 'hex')
    {
        if (!validator.isHexadecimal(input))
        {
            errors[name] = {
                rule: rule.name,
                message: rule.message
            };
            pass = false;
            err = true;
        }
        else
        {
            errors[name] = {};
        }
    }

    else if (rule.name == 'lowercase')
    {
        if (!validator.isLowercase(input))
        {
            errors[name] = {
                rule: rule.name,
                message: rule.message
            };
            pass = false;
            err = true;
        }
        else
        {
            errors[name] = {};
        }
    }

    else if (rule.name == 'uppercase')
    {
        if (!validator.isUppercase(input))
        {
            errors[name] = {
                rule: rule.name,
                message: rule.message
            };
            pass = false;
            err = true;
        }
        else
        {
            errors[name] = {};
        }
    }

    else if (rule.name == 'int')
    {
        if (!validator.isInt(input))
        {
            errors[name] = {
                rule: rule.name,
                message: rule.message
            };
            pass = false;
            err = true;
        }
        else
        {
            errors[name] = {};
        }
    }

    else if (rule.name == 'float')
    {
        if (!validator.isFloat(input))
        {
            errors[name] = {
                rule: rule.name,
                message: rule.message
            };
            pass = false;
            err = true;
        }
        else
        {
            errors[name] = {};
        }
    }

    else if (rule.name.divisible)
    {
        if (!validator.isDivisibleBy(input, rule.name.divisible))
        {
            errors[name] = {
                rule: 'divisible',
                message: rule.message
            };
            pass = false;
            err = true;
        }
        else
        {
            errors[name] = {};
        }
    }

    else if (rule.name.min)
    {
        if (!validator.isLength(input, rule.name.min))
        {
            errors[name] = {
                rule: 'min',
                message: rule.message
            };
            pass = false;
            err = true;
        }
        else
        {
            errors[name] = {};
        }
    }

    else if (rule.name.max)
    {
        if (!validator.isLength(input, 0, rule.name.max))
        {
            errors[name] = {
                rule: 'max',
                message: rule.message
            };
            pass = false;
            err = true;
        }
        else
        {
            errors[name] = {};
        }
    }

    else if (rule.name == 'date')
    {
        if (!validator.isDate(input))
        {
            errors[name] = {
                rule: 'date',
                message: rule.message
            };
            pass = false;
            err = true;
        }
        else
        {
            errors[name] = {};
        }
    }

    else if (rule.name == 'json')
    {
        if (!validator.isJSON(input))
        {
            errors[name] = {
                rule: 'json',
                message: rule.message
            };
            pass = false;
            err = true;
        }
        else
        {
            errors[name] = {};
        }
    }

    return err;

}
